pub enum RemoteSessionObservationStreamItem {
Event(RemoteSessionObservationEvent),
Gap {
observation: RemoteSessionObservation,
gap: RemoteLiveReplayGap,
},
}Variants
Event(RemoteSessionObservationEvent)
A replayed or live session observation event encoded as remote DTOs.
Gap
A recoverable replay gap with a fresh remote observation snapshot.