select_claim_prefix

Function select_claim_prefix 

pub fn select_claim_prefix(
    candidates: &[ClaimCandidate],
    boundary: QueuedWorkClaimBoundary,
    max_batches: usize,
) -> usize
Select the prefix of candidates that a single claim may take.

Returns the number of leading candidates to claim (0 means no claim):