pub struct ProcessStarted {
pub owner: LeaseOwnerIdentity,
pub started_at_ms: u64,
}Expand description
Durable “execution started” fact: which owner began executing the row and when. The runner writes it under its live lease immediately before executing so the sweep can distinguish an OwnerBound row that has started (never re-run) from one that has not (runnable by anyone). First-writer-wins.
Fields
owner: LeaseOwnerIdentitystarted_at_ms: u64Trait Implementations
Sourceimpl Clone for ProcessStarted
impl Clone for ProcessStarted
Sourcefn clone(&self) -> ProcessStarted
fn clone(&self) -> ProcessStarted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessStarted
impl Debug for ProcessStarted
Sourceimpl<'de> Deserialize<'de> for ProcessStarted
impl<'de> Deserialize<'de> for ProcessStarted
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProcessStarted, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProcessStarted, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProcessStarted
Sourceimpl From<ProcessStarted> for RemoteProcessStarted
impl From<ProcessStarted> for RemoteProcessStarted
Sourcefn from(value: ProcessStarted) -> RemoteProcessStarted
fn from(value: ProcessStarted) -> RemoteProcessStarted
Converts to this type from the input type.
Sourceimpl PartialEq for ProcessStarted
impl PartialEq for ProcessStarted
Sourcefn eq(&self, other: &ProcessStarted) -> bool
fn eq(&self, other: &ProcessStarted) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessStarted
impl Serialize for ProcessStarted
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ProcessStarted
Sourceimpl TryFrom<RemoteProcessStarted> for ProcessStarted
impl TryFrom<RemoteProcessStarted> for ProcessStarted
Sourcetype Error = RemoteProtocolError
type Error = RemoteProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: RemoteProcessStarted,
) -> Result<ProcessStarted, <ProcessStarted as TryFrom<RemoteProcessStarted>>::Error>
fn try_from( value: RemoteProcessStarted, ) -> Result<ProcessStarted, <ProcessStarted as TryFrom<RemoteProcessStarted>>::Error>
Performs the conversion.