pub struct ReasoningCapability {
pub efforts: Vec<String>,
pub default_effort: Option<String>,
pub aliases: BTreeMap<String, String>,
pub encoding: ReasoningEncoding,
pub mandatory: bool,
}Expand description
What reasoning/effort the model exposes and how effort maps onto the wire.
Fields
efforts: Vec<String>default_effort: Option<String>aliases: BTreeMap<String, String>requested-effort -> canonical-effort clamp map (e.g. “xhigh” -> “max”, “minimal” -> “low”)
encoding: ReasoningEncodingmandatory: boolTrait Implementations
Sourceimpl Clone for ReasoningCapability
impl Clone for ReasoningCapability
Sourcefn clone(&self) -> ReasoningCapability
fn clone(&self) -> ReasoningCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReasoningCapability
impl Debug for ReasoningCapability
Sourceimpl Default for ReasoningCapability
impl Default for ReasoningCapability
Sourcefn default() -> ReasoningCapability
fn default() -> ReasoningCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReasoningCapability
impl<'de> Deserialize<'de> for ReasoningCapability
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReasoningCapability, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReasoningCapability, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReasoningCapability
Sourceimpl From<RemoteReasoningCapability> for ReasoningCapability
impl From<RemoteReasoningCapability> for ReasoningCapability
Sourcefn from(value: RemoteReasoningCapability) -> ReasoningCapability
fn from(value: RemoteReasoningCapability) -> ReasoningCapability
Converts to this type from the input type.
Sourceimpl JsonSchema for ReasoningCapability
impl JsonSchema for ReasoningCapability
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReasoningCapability
impl PartialEq for ReasoningCapability
Sourceimpl Serialize for ReasoningCapability
impl Serialize for ReasoningCapability
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ReasoningCapability