pub struct RemoteProviderFileScope {
pub provider: String,
pub credential_scope: String,
}Fields
provider: Stringcredential_scope: StringTrait Implementations
Sourceimpl Clone for RemoteProviderFileScope
impl Clone for RemoteProviderFileScope
Sourcefn clone(&self) -> RemoteProviderFileScope
fn clone(&self) -> RemoteProviderFileScope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteProviderFileScope
impl Debug for RemoteProviderFileScope
Sourceimpl<'de> Deserialize<'de> for RemoteProviderFileScope
impl<'de> Deserialize<'de> for RemoteProviderFileScope
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RemoteProviderFileScope, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RemoteProviderFileScope, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RemoteProviderFileScope
Sourceimpl From<ProviderFileScope> for RemoteProviderFileScope
impl From<ProviderFileScope> for RemoteProviderFileScope
Sourcefn from(value: ProviderFileScope) -> RemoteProviderFileScope
fn from(value: ProviderFileScope) -> RemoteProviderFileScope
Converts to this type from the input type.
Sourceimpl From<RemoteProviderFileScope> for ProviderFileScope
impl From<RemoteProviderFileScope> for ProviderFileScope
Sourcefn from(value: RemoteProviderFileScope) -> ProviderFileScope
fn from(value: RemoteProviderFileScope) -> ProviderFileScope
Converts to this type from the input type.
Sourceimpl JsonSchema for RemoteProviderFileScope
impl JsonSchema for RemoteProviderFileScope
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteProviderFileScope
impl PartialEq for RemoteProviderFileScope
Sourceimpl Serialize for RemoteProviderFileScope
impl Serialize for RemoteProviderFileScope
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RemoteProviderFileScope