pub struct RemoteProcessStarted {
pub owner: Value,
pub started_at_ms: u64,
}Expand description
Wire mirror of the durable execution-started fact.
Fields
owner: Valuestarted_at_ms: u64Trait Implementations
Sourceimpl Clone for RemoteProcessStarted
impl Clone for RemoteProcessStarted
Sourcefn clone(&self) -> RemoteProcessStarted
fn clone(&self) -> RemoteProcessStarted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteProcessStarted
impl Debug for RemoteProcessStarted
Sourceimpl<'de> Deserialize<'de> for RemoteProcessStarted
impl<'de> Deserialize<'de> for RemoteProcessStarted
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RemoteProcessStarted, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RemoteProcessStarted, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ProcessStarted> for RemoteProcessStarted
impl From<ProcessStarted> for RemoteProcessStarted
Sourcefn from(value: ProcessStarted) -> RemoteProcessStarted
fn from(value: ProcessStarted) -> RemoteProcessStarted
Converts to this type from the input type.
Sourceimpl JsonSchema for RemoteProcessStarted
impl JsonSchema for RemoteProcessStarted
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RemoteProcessStarted
impl PartialEq for RemoteProcessStarted
Sourcefn eq(&self, other: &RemoteProcessStarted) -> bool
fn eq(&self, other: &RemoteProcessStarted) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RemoteProcessStarted
impl Serialize for RemoteProcessStarted
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for RemoteProcessStarted
Sourceimpl TryFrom<RemoteProcessStarted> for ProcessStarted
impl TryFrom<RemoteProcessStarted> for ProcessStarted
Sourcetype Error = RemoteProtocolError
type Error = RemoteProtocolError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: RemoteProcessStarted,
) -> Result<ProcessStarted, <ProcessStarted as TryFrom<RemoteProcessStarted>>::Error>
fn try_from( value: RemoteProcessStarted, ) -> Result<ProcessStarted, <ProcessStarted as TryFrom<RemoteProcessStarted>>::Error>
Performs the conversion.