pub struct LashCore { /* private fields */ }Implementations
Sourceimpl LashCore
impl LashCore
pub fn builder() -> LashCoreBuilder
Sourcepub fn standard() -> LashCoreBuilder
pub fn standard() -> LashCoreBuilder
Preset for standard mode.
Storage and effect durability are still host-owned choices. Provide the
effect host, Lashlang artifact store, and attachment store facets with
the builder setters before calling LashCoreBuilder::build.
Sourcepub fn rlm() -> LashCoreBuilder
pub fn rlm() -> LashCoreBuilder
Preset for rlm mode.
Storage and effect durability are still host-owned choices. Provide the
effect host, Lashlang artifact store, and attachment store facets with
the builder setters before calling LashCoreBuilder::build.
pub fn session(&self, session_id: impl Into<String>) -> SessionBuilder
pub fn host_events(&self) -> HostEventsControl
pub async fn delete_session( &self, session_id: impl AsRef<str>, ) -> Result<SessionDeleteReport>
pub async fn delete_session_with_effect_scope( &self, session_id: impl AsRef<str>, scoped_effect_controller: ScopedEffectController<'_>, ) -> Result<SessionDeleteReport>
pub fn installed_modes(&self) -> impl Iterator<Item = &ModeId>
pub fn process_observer(&self) -> Option<&ProcessWorkObserver>
pub fn process_registry(&self) -> Option<Arc<dyn ProcessRegistry>>
pub fn durable_process_worker_config( &self, ) -> Result<DurableProcessWorkerConfig>
pub fn durable_process_worker_config_with_plugins( &self, extra_plugin_factories: impl IntoIterator<Item = Arc<dyn PluginFactory>>, ) -> Result<DurableProcessWorkerConfig>