pub struct AdvancedTurn { /* private fields */ }Expand description
Lower-level turn execution that exposes the raw runtime event stream.
Reachable via TurnBuilder::advanced. Most applications should use
TurnBuilder::stream_to for semantic turn activity; benchmarks and
diagnostics use this when they need the same low-level event stream as the
runtime trace.
Implementations
Sourceimpl AdvancedTurn
impl AdvancedTurn
pub async fn run_with_scope( self, scoped_effect_controller: ScopedEffectController<'_>, ) -> Result<TurnOutput>
pub async fn collect_with_scope( self, events: &dyn TurnActivitySink, scoped_effect_controller: ScopedEffectController<'_>, ) -> Result<TurnOutput>
pub async fn stream_to_with_scope( self, events: &dyn TurnActivitySink, scoped_effect_controller: ScopedEffectController<'_>, ) -> Result<TurnResult>
pub fn stream_with_scope( self, scoped_effect_controller: ScopedEffectController<'static>, ) -> Result<TurnStream>
Sourcepub async fn collect_session_events_with_scope(
self,
events: &dyn EventSink,
scoped_effect_controller: ScopedEffectController<'_>,
) -> Result<TurnResult>
pub async fn collect_session_events_with_scope( self, events: &dyn EventSink, scoped_effect_controller: ScopedEffectController<'_>, ) -> Result<TurnResult>
Run the turn while sending raw lower-level runtime events to events.